'''
This demo runs and plots a several Spiking neurons stimulated with a 
range of currents. This uses the Morris-Lecar neuron from `Scholarpedia
<http://www.scholarpedia.org/article/Morris-Lecar_model>`.
'''

#import the SpikeStream library
from SpikeStream import *

DT           = 0.05 #ms
LOW_CURRENT  = 0 #units ??? 
HIGH_CURRENT = 100 #units ???
NTRIAL       = 10 #Run a new simulation for each current value
NTDIV        = NTRIAL #we want to run all the replocas at once
TIME         = 500 #ms
STEPS        = int(TIME/DT) #time steps to simulate

#Set up simulation framework
sim = newSim(NTRIAL,NTDIV,False,DT)

#add 1 MorrisLecar neuron to the simulation
neuron = sim.newModel(1,MorrisLecar())

#add a current to our neuron
#one way to do this would be to write a custom current that looks at
#which replica is running
neuron.newInput(CustomCurrent("input_current += (replica_num/%f)*%s+(1.0-replica_num/%f)*%s;"%(NTRIAL,HIGH_CURRENT,NTRIAL,LOW_CURRENT)))

#add a probe to record voltage
voltage = State(sim,neuron,'v')

#execute the simulation
sim.prepare_and_run(STEPS)

#a quick plot
fig,ax = newplot(voltage.data,'Timestep (dt=%sms)'%DT,'Voltage (mV)','Voltage Trace')
savefig_allformats(fig,"multi_neuron_plot")







