'''
This demo runs and plots a single Spiking neuron.
'''

#import the SpikeStream library
from SpikeStream import *

DT      = 0.05 #ms
CURRENT = 50 #units ??? 
NTRIAL  = 1 #we only want to run one simulation
NTDIV   = 1 #we only want to run one division
TIME    = 500 #ms
STEPS   = int(TIME/DT) #time steps to simulate

#Set up simulation framework
sim = newSim(NTRIAL,NTDIV,False,DT)

#add 1 MorrisLecar neuron to the simulation
neuron = sim.newModel(1,MorrisLecar())

#add a current to our neuron
neuron.newInput(CustomCurrent("input_current += %s;"%CURRENT))

#add a probe to record voltage
voltage = State(sim,neuron,'v')

#execute the simulation
sim.prepare_and_run(STEPS)

#a quick plot
fig,ax = newplot(voltage.data,'Timestep (dt=%sms)'%DT,'Voltage (mV)','Voltage Trace')
savefig_allformats(fig,"single_neuron_plot")






